<template>
  <div class='editable-cell'>
    <div v-if='editable' class='editable-cell-input-wrapper'>
      <a-input :value='value' @change='handleChange' @pressEnter='check' />
      <a-icon
        class='editable-cell-icon-check'
        type='check'
        @click='check'
      />
    </div>
    <div v-else class='editable-cell-text-wrapper'>
      {{ value || ' ' }}
      <a-icon class='editable-cell-icon' type='edit' @click='edit' />
    </div>
  </div>
</template>

<script>
import EquipmentModel from './EquipmentModel'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'

export default {
  props: {
    text: String
  },
  name: 'Equipment',
  mixins: [JeecgListMixin],
  components: {
    EquipmentModel,
    JDictSelectTag,
    JInput,
    JEllipsis
  },
  data() {
    return {
      value: this.text,
      editable: false
    }
  },
  watch: {
    projectId: {
      handler(newVal, oldVal) {
        this.loadData()
        this.projectClassify = newVal
      }
    }
  },
  methods: {
    handleChange(e) {
      const value = e.target.value
      this.value = value
    },
    check() {
      this.editable = false
      this.$emit('change', this.value)
    },
    edit() {
      this.editable = true
    }
  }
}
</script>
<style>
@import '~@assets/less/common.less';

</style>
